summaryrefslogtreecommitdiff
path: root/test/parallel/test-http2-respond-with-fd-errors.js
diff options
context:
space:
mode:
Diffstat (limited to 'test/parallel/test-http2-respond-with-fd-errors.js')
-rw-r--r--test/parallel/test-http2-respond-with-fd-errors.js24
1 files changed, 5 insertions, 19 deletions
diff --git a/test/parallel/test-http2-respond-with-fd-errors.js b/test/parallel/test-http2-respond-with-fd-errors.js
index 920c3eb908..c8ecfcf5f3 100644
--- a/test/parallel/test-http2-respond-with-fd-errors.js
+++ b/test/parallel/test-http2-respond-with-fd-errors.js
@@ -11,32 +11,18 @@ const http2 = require('http2');
const {
constants,
- Http2Session,
+ Http2Stream,
nghttp2ErrorString
} = process.binding('http2');
// tests error handling within processRespondWithFD
// (called by respondWithFD & respondWithFile)
-// - NGHTTP2_ERR_NOMEM (should emit session error)
// - every other NGHTTP2 error from binding (should emit stream error)
const fname = fixtures.path('elipses.txt');
-const specificTestKeys = [
- 'NGHTTP2_ERR_NOMEM'
-];
-
-const specificTests = [
- {
- ngError: constants.NGHTTP2_ERR_NOMEM,
- error: {
- code: 'ERR_OUTOFMEMORY',
- type: Error,
- message: 'Out of memory'
- },
- type: 'session'
- }
-];
+const specificTestKeys = [];
+const specificTests = [];
const genericTests = Object.getOwnPropertyNames(constants)
.filter((key) => (
@@ -57,8 +43,8 @@ const tests = specificTests.concat(genericTests);
let currentError;
-// mock submitFile because we only care about testing error handling
-Http2Session.prototype.submitFile = () => currentError.ngError;
+// mock respondFD because we only care about testing error handling
+Http2Stream.prototype.respondFD = () => currentError.ngError;
const server = http2.createServer();
server.on('stream', common.mustCall((stream, headers) => {